@@ -22,21 +22,19 @@ placed in ./aws4_testsuite, and we're using those to dynamically
 generate testcases based on these files.
 
 """
-import os
-import logging
-import io
 import datetime
+import io
+import logging
+import os
 import re
 
 import pytest
 
-from tests import FreezeTime
-
 import botocore.auth
 from botocore.awsrequest import AWSRequest
-from botocore.compat import six, urlsplit, parse_qsl
+from botocore.compat import parse_qsl, six, urlsplit
 from botocore.credentials import Credentials
-
+from tests import FreezeTime
 
 SECRET_KEY = "wJalrXUtnFEMI/K7MDENG+bPxRfiCYEXAMPLEKEY"
 ACCESS_KEY = 'AKIDEXAMPLE'
@@ -87,7 +85,9 @@ def generate_test_cases():
         if not any(f.endswith('.req') for f in filenames):
             continue
 
-        test_case = os.path.relpath(dirpath, TESTSUITE_DIR)
+        test_case = os.path.relpath(dirpath, TESTSUITE_DIR).replace(
+            os.sep, '/'
+        )
         if test_case in TESTS_TO_IGNORE:
             log.debug("Skipping test: %s", test_case)
             continue
