@@ -1,17 +1,26 @@
 import socket
 
 import pytest
-from urllib3.exceptions import NewConnectionError, ProtocolError
+from urllib3.exceptions import NewConnectionError, ProtocolError, ProxyError
 
+from botocore.awsrequest import (
+    AWSHTTPConnectionPool,
+    AWSHTTPSConnectionPool,
+    AWSRequest,
+)
+from botocore.exceptions import (
+    ConnectionClosedError,
+    EndpointConnectionError,
+    ProxyConnectionError,
+)
+from botocore.httpsession import (
+    ProxyConfiguration,
+    URLLib3Session,
+    get_cert_path,
+    mask_proxy_url,
+)
 from tests import mock, unittest
 
-from botocore.vendored import six
-from botocore.awsrequest import AWSRequest
-from botocore.awsrequest import AWSHTTPConnectionPool, AWSHTTPSConnectionPool
-from botocore.httpsession import get_cert_path
-from botocore.httpsession import URLLib3Session, ProxyConfiguration
-from botocore.exceptions import ConnectionClosedError, EndpointConnectionError
-
 
 class TestProxyConfiguration(unittest.TestCase):
     def setUp(self):
@@ -64,6 +73,56 @@ class TestHttpSessionUtils(unittest.TestCase):
             self.assertEqual(path, cert_path)
 
 
+@pytest.mark.parametrize(
+    'proxy_url, expected_mask_url',
+    (
+
+        (
+            'http://myproxy.amazonaws.com',
+            'http://myproxy.amazonaws.com'
+        ),
+        (
+            'http://user@myproxy.amazonaws.com',
+            'http://***@myproxy.amazonaws.com'
+        ),
+        (
+            'http://user:pass@myproxy.amazonaws.com',
+            'http://***:***@myproxy.amazonaws.com'
+        ),
+        (
+            'https://user:pass@myproxy.amazonaws.com',
+            'https://***:***@myproxy.amazonaws.com'
+        ),
+        (
+            'http://user:pass@localhost',
+            'http://***:***@localhost'
+        ),
+        (
+            'http://user:pass@localhost:80',
+            'http://***:***@localhost:80'
+        ),
+        (
+            'http://user:pass@userpass.com',
+            'http://***:***@userpass.com'
+        ),
+        (
+            'http://user:pass@192.168.1.1',
+            'http://***:***@192.168.1.1'
+        ),
+        (
+            'http://user:pass@[::1]',
+            'http://***:***@[::1]'
+        ),
+        (
+            'http://user:pass@[::1]:80',
+            'http://***:***@[::1]:80'
+        ),
+    )
+)
+def test_mask_proxy_url(proxy_url, expected_mask_url):
+    assert mask_proxy_url(proxy_url) == expected_mask_url
+
+
 class TestURLLib3Session(unittest.TestCase):
     def setUp(self):
         self.request = AWSRequest(
@@ -236,7 +295,7 @@ class TestURLLib3Session(unittest.TestCase):
 
     def test_https_proxy_scheme_forwarding_https_url(self):
         proxies = {'https': 'https://proxy.com'}
-        proxies_config = {"proxy_use_forwarding_for_https":  True}
+        proxies_config = {"proxy_use_forwarding_for_https": True}
         session = URLLib3Session(proxies=proxies, proxies_config=proxies_config)
         self.request.url = 'https://example.com/'
         session.send(self.request.prepare())
@@ -393,15 +452,23 @@ class TestURLLib3Session(unittest.TestCase):
     def test_catches_new_connection_error(self):
         error = NewConnectionError(None, None)
         with pytest.raises(EndpointConnectionError):
-           self.make_request_with_error(error)
+            self.make_request_with_error(error)
 
     def test_catches_bad_status_line(self):
         error = ProtocolError(None)
         with pytest.raises(ConnectionClosedError):
             self.make_request_with_error(error)
 
+    def test_catches_proxy_error(self):
+        self.connection.urlopen.side_effect = ProxyError('test', None)
+        session = URLLib3Session(proxies={'http': 'http://user:pass@proxy.com'})
+        with pytest.raises(ProxyConnectionError) as e:
+            session.send(self.request.prepare())
+        assert 'user:pass' not in str(e.value)
+        assert 'http://***:***@proxy.com' in str(e.value)
+
     def test_aws_connection_classes_are_used(self):
-        session = URLLib3Session()
+        session = URLLib3Session() # noqa
         # ensure the pool manager is using the correct classes
         http_class = self.pool_manager.pool_classes_by_scheme.get('http')
         self.assertIs(http_class, AWSHTTPConnectionPool)
